<?php

/***************************************************************************
 *                            lang_admin.php [Danish]
 *                              -------------------
 *     begin                : Sat Dec 16 2000
 *     copyright            : (C) 2001 The phpBB Group
 *     email                : support@phpbb.com
 *
 *     $Id: lang_admin.php 1.36.0.1 2004/08/23 02:31:19 AlK
 *
 ****************************************************************************/
/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

/* CONTRIBUTORS
    Translation done by Ken Christensen (Dalixam) 2.0.4
    Updates, overhauls to 2.0.10 by AlleyKat 
	*/

//
// Format is same as lang_main
//

//
// Modules, this replaces the keys used
// in the modules[][] arrays in each module file
//
$lang['General'] = "Generel Administrator";
$lang['Users'] = "Bruger Administrator";
$lang['Groups'] = "Gruppe Administrator";
$lang['Forums'] = "Forum Administrator";
$lang['Styles'] = "Layout Administrator";

$lang['Configuration'] = "Konfiguration";
$lang['Permissions'] = "Tilladelser";
$lang['Manage'] = "Redigering";
$lang['Disallow'] = "Forbyd bestemte navne";
$lang['Prune'] = "Beskr";
$lang['Mass_Email'] = "Gruppe email";
$lang['Ranks'] = "Rang";
$lang['Smilies'] = "Smilies";
$lang['Ban_Management'] = "Forbyd Kontrol";
$lang['Word_Censor'] = "Ordcensurerer";
$lang['Export'] = "Eksportr";
$lang['Create_new'] = "Opret";
$lang['Add_new'] = "Tilfj";
$lang['Backup_DB'] = "Backup Database";
$lang['Restore_DB'] = "Genopret Database";


//
// Index
//
$lang['Admin'] = "Administration";
$lang['Not_admin'] = "Du er ikke autoriseret til at redigere dette forum";
$lang['Welcome_phpBB'] = "Velkommen til phpBB";
$lang['Admin_intro'] = "Tak fordi du valgte phpBB som dit forum. Denne skrm vil give dig et hurtigt overblik over alle de forskellige statistikker, der er tilgngelige om dit forum. Du kan komme tilbage til denne side ved at klikke p <u>Administrationsindeks</u> linket i venstre side. For at vende tilbage til dit forums indeksside kan du klikke p linket eller phpBB logoet, der ogs befinder sig i venstre side. De andre links i venstre side lader dig kontrollere og redigere hver eneste aspekt af dit forum; hver enkelt side indeholder instruktioner om, hvordan du bruger de forskellige vrktjer.";
$lang['Main_index'] = "Forumindeks";
$lang['Forum_stats'] = "Forum Statistikker";
$lang['Admin_Index'] = "Administrationsindeks";
$lang['Preview_forum'] = "Smugkig p forummet";

$lang['Click_return_admin_index'] = "Klik %sher%s for at vende tilbage til Administrationsindekset";

$lang['Statistic'] = "Statistikker";
$lang['Value'] = "Vrdi";
$lang['Number_posts'] = "Antal indlg";
$lang['Posts_per_day'] = "Indlg pr. dag";
$lang['Number_topics'] = "Antal emner";
$lang['Topics_per_day'] = "Emner pr. dag";
$lang['Number_users'] = "Antal brugere";
$lang['Users_per_day'] = "Brugere pr. dag";
$lang['Board_started'] = "Forum oprettelse";
$lang['Avatar_dir_size'] = "Avatar-bibliotekets strrelse";
$lang['Database_size'] = "Database-strrelse";
$lang['Gzip_compression'] ="Gzip komprimering";
$lang['Not_available'] = "Ikke tilgngelig";

$lang['ON'] = "Slet til"; // Dette er for GZip komprimering
$lang['OFF'] = "Slet fra"; 


//
// DB Utils
//
$lang['Database_Utilities'] = "Database-vrktjer";

$lang['Restore'] = "Genopret";
$lang['Backup'] = "Backup";
$lang['Restore_explain'] = "Dette vil genoprette alle phpBB tabeller fra en gemt fil. Hvis din server understtter det, kan du uploade en gzip komprimeret tekstfil og s bliver den automatisk dekomprimeret. <b>ADVARSEL</b> Dette vil overskrive alle eksisterende data. Genoprettelsen kan tage lang tid at udfre, forlad venligst ikke denne side fr den er fuldfrt.";
$lang['Backup_explain'] = "Her kan du lave en backup, af alle dine data, der relaterer til phpBB. Hvis du har andre tabeller i din database, som du ogs nsker, at lave en backup af, skal du indtaste deres navne adskilt af kommaer i Yderligere Tabeller feltet nedenunder. Hvis din server understtter det, kan du gzip komprimere filen fr du downloader den for at reducere dens strrrelse.";

$lang['Backup_options'] = "Backup muligheder";
$lang['Start_backup'] = "Start backup";
$lang['Full_backup'] = "Fuld backup";
$lang['Structure_backup'] = "Kun Struktur backup";
$lang['Data_backup'] = "Kun Data backup";
$lang['Additional_tables'] = "Yderligere Tabeller";
$lang['Gzip_compress'] = "Gzip komprimr fil";
$lang['Select_file'] = "Vlg en fil";
$lang['Start_Restore'] = "Start Genopret";

$lang['Restore_success'] = "Databasen er blevet korrekt genoprettet.<br /><br />Dit forum skulle nu vre i den tilstand, det var, da backuppen blev foretaget";
$lang['Backup_download'] = "Din download vil begynde om kort tid, vent venligst til den begynder";
$lang['Backups_not_supported'] = "Desvrre, backups af databaser fra dit database-system understttes p nuvrende tidspunkt ikke";

$lang['Restore_Error_uploading'] = "Der skete en fejl under upload af backup-filen";
$lang['Restore_Error_filename'] = "Der er et problem med filens navn, prv venligst med en alternativ fil";
$lang['Restore_Error_decompress'] = "Gzip-filen kan ikke dekomprimeres, upload venligst en ren tekstversion";
$lang['Restore_Error_no_file'] = "Ingen fil blev uploaded";


//
// Auth pages
//
$lang['Select_a_User'] = "Vlg en Bruger";
$lang['Select_a_Group'] = "Vlg en Gruppe";
$lang['Select_a_Forum'] = "Vlg et Forum";
$lang['Auth_Control_User'] = "Brugerrettigheder kontrolside"; 
$lang['Auth_Control_Group'] = "Grupperettigheder kontrolside"; 
$lang['Auth_Control_Forum'] = "Forumrettigheder kontrolside"; 
$lang['Look_up_User'] = "Sl Brugeren op"; 
$lang['Look_up_Group'] = "Sl Gruppen op"; 
$lang['Look_up_Forum'] = "Vis forum"; 

$lang['Group_auth_explain'] = "Her kan du ndre rettighederne og redaktrstatus for hver enkelt brugergruppe. Glem ikke nr du ndrer grupperettigheder, at individuelle brugerrettigheder mske stadig tillader at brugeren har adgang til forummerne, etc. Du bliver advaret, hvis dette er tilfldet.";
$lang['User_auth_explain'] = "Her kan du ndre rettighederne og redaktrstatus for hver enkelt bruger. Glem ikke nr du ndrer brugerrettigheder, at grupperettigheder mske stadig tillader at brugeren har adgang til forummerne, etc. Du bliver advaret, hvis dette er tilfldet.";
$lang['Forum_auth_explain'] = "Her kan du ndre autoriseringsniveauer for de enkelte fora. Du har bde en simpel og avanceret metode til rdighed. Den avancerede metode tillader strre kontrol af hvert enkelt forum. Husk, at nr du ndrer forummernes autoriseringsniveauerne, pvirker det hvilke brugere der kan udfre de forskellige ting i dem.";

$lang['Simple_mode'] = "Simpel Metode";
$lang['Advanced_mode'] = "Avanceret Metode";
$lang['Moderator_status'] = "Redaktr status";

$lang['Allowed_Access'] = "Tilladt Adgang";
$lang['Disallowed_Access'] = "Ngtet Adgang";
$lang['Is_Moderator'] = "Er Redaktr";
$lang['Not_Moderator'] = "Er ikke Redaktr";

$lang['Conflict_warning'] = "Advarsel om Autorisationskonflikt";
$lang['Conflict_access_userauth'] = "Denne bruger har stadig adgangsrettigheder til dette forum via et gruppemedlemsskab. Du skal nok ndre gruppens rettigheder eller fjerne denne bruger fra gruppen, for at forhindre at vedkommende har adgangsrettigheder. Gruppens rettigheder (og forummerne involveret) er nvnt herunder.";
$lang['Conflict_mod_userauth'] = "Denne bruger har stadig redaktrrettigheder til dette forum via et gruppemedlemsskab. Du skal nok ndre gruppens rettigheder eller fjerne denne bruger fra gruppen, for at forhindre at vedkommende har redaktrrettigheder. Gruppens rettigheder (og forummerne involveret) er nvnt herunder.";

$lang['Conflict_access_groupauth'] = "Den flgende bruger (eller brugere) har stadig adgangsrettigheder til dette forum via deres brugerrettigheder. Du skal nok brugerrettighederne for at forhindre dem i, at have adgangsrettigheder. Brugernes rettigheder (og forummerne involveret) er nvnt herunder.";
$lang['Conflict_mod_groupauth'] = "Den flgende bruger (eller brugere) har stadig redaktrrettigheder til dette forum via deres brugerrettigheder. Du skal nok brugerrettighederne for at forhindre dem i, at have redaktrrettigheder. Brugernes rettigheder (og forummerne involveret) er nvnt herunder.";

$lang['Public'] = "Offentlig";
$lang['Private'] = "Privat";
$lang['Registered'] = "Registeret";
$lang['Administrators'] = "Administratorer";
$lang['Hidden'] = "Skjult";

// These are displayed in the drop down boxes for advanced
// mode forum auth, try and keep them short!
$lang['Forum_ALL'] = "ALLE";
$lang['Forum_REG'] = "REG";
$lang['Forum_PRIVATE'] = "PRIVAT";
$lang['Forum_MOD'] = "REDAKTR";
$lang['Forum_ADMIN'] = "ADMIN";

$lang['View'] = "Se";
$lang['Read'] = "Lse";
$lang['Post'] = "Indlg";
$lang['Reply'] = "Svar";
$lang['Edit'] = "ndre";
$lang['Delete'] = "Slet";
$lang['Sticky'] = "Opslag";
$lang['Announce'] = "Bekendtgre"; 
$lang['Vote'] = "Stem";
$lang['Pollcreate'] = "Opret afstemning";

$lang['Permissions'] = "Rettigheder";
$lang['Simple_Permission'] = "Simpel Rettighed";

$lang['User_Level'] = "Brugerniveau"; 
$lang['Auth_User'] = "Bruger";
$lang['Auth_Admin'] = "Administrator";
$lang['Group_memberships'] = "Medlemsskaber til brugergrupper";
$lang['Usergroup_members'] = "Denne gruppe har flgende medlemmer";

$lang['Forum_auth_updated'] = "Forumrettigheder opdateret";
$lang['User_auth_updated'] = "Brugerrettigheder opdateret";
$lang['Group_auth_updated'] = "Grupperettigheder opdateret";

$lang['Auth_updated'] = "Rettigheder er blevet opdateret";
$lang['Click_return_userauth'] = "Klik %sher%s for at vende tilbage til Brugerrettigheder";
$lang['Click_return_groupauth'] = "Klik %sher%s for at vende tilbage til Grupperettigheder";
$lang['Click_return_forumauth'] = "Klik %sher%s for at vende tilbage til Forumrettigheder";


//
// Banning
//
$lang['Ban_control'] = "Kontrollering af bandlysninger";
$lang['Ban_explain'] = "Her kan du kontrollere bandlysning af brugere. Du kan opn dette, ved enten at bandlyse en specifik bruger, en eller flere IP adresser eller domainnavne. Disse metoder forhindrer en bruger i overhovedet at f adgang til dit forums indeksside. For at forhindre, at en bruger registrerer sig under en andet brugernavn, kan du ogs bandlyse en email adresse. Husk, bandlysning af en email adresse vil ikke forhindre den bruger i at logge p eller komme med nye indlg p dit forum, du skal bruge en af de frstnvnte metoder, for at forhindre dette.";
$lang['Ban_explain_warn'] = "Bemrk venligst, at hvis du indtaster en rkke IP adresser vil dette resultere i, at alle adresserne mellem start og slut bliver tilfjet listen over bandlyste IP adresser. Forsg p, at minimere antallet af adresser tilfjet til databasen, vil blive foretaget ved automatisk at introducere jokere, nr det er passende. Hvis du virkelig vil indtaste en rkke adresser, s prv at minimere rkken eller endnu bedre, indtast specifikke adresser.";

$lang['Select_username'] = "Vlg et Brugernavn";
$lang['Select_ip'] = "Vlg en IP Adresse";
$lang['Select_email'] = "Vlg en Email Adresse";

$lang['Ban_username'] = "Bandlys en eller flere specifikke brugere";
$lang['Ban_username_explain'] = 'Du kan bandlyse flere brugere p en gang ved at bruge den rette kombination af mus og tastatur for din computer og browser';

$lang['Ban_IP'] = "Bandlys en eller flere IP-adresser eller domnenavne";
$lang['IP_hostname'] = "IP-adresser eller domnenavne";
$lang['Ban_IP_explain'] = "For at angive flere IP adresser eller domnenavne skal du adskille dem med kommaer. For at angive en rkke IP adresser skal du adskille starten og slutningen med en bindestreg (-), for at angive en joker skal du bruge *";

$lang['Ban_email'] = "Bandlys en eller flere adresser";
$lang['Ban_email_explain'] = "For at angive flere email adresser skal du adskille dem med kommaer. For at angive en joker skal du bruge *, for eksempel *@hotmail.com";

$lang['Unban_username'] = "Ophv bandlysning p en eller flere brugere";
$lang['Unban_username_explain'] = "Du kan ophve bandlysning af flere brugere p en gang, ved at bruge den passende kombination af mus og tastatur til din computer og browser.";

$lang['Unban_IP'] = "Ophv bandlysning p en eller flere IP adresser";
$lang['Unban_IP_explain'] = "Du kan ophve bandlysning p en eller flere IP adresser p en gang, ved at bruge den passende kombination af mus og tastatur til din computer og browser.";

$lang['Unban_email'] = "Ophv bandlysning p en eller flere email adresser.";
$lang['Unban_email_explain'] = "Du kan ophve bandlysning p flere email adresser p en gang, ved at bruge den passende kombination af mus og tastatur til din computer og browser.";

$lang['No_banned_users'] = "Ingen bandlyste brugernavne";
$lang['No_banned_ip'] = "Ingen bandlyste IP adresser";
$lang['No_banned_email'] = "Ingen bandlyste email adresser";

$lang['Ban_update_sucessful'] = "Listen med oplysningerne om bandlysninger er korrekt opdateret.";
$lang['Click_return_banadmin'] = "Klik %sher%s for at vende tilbage til Kontrol af bandlysninger";


//
// Configuration
//
$lang['General_Config'] = "Generel Konfiguration";
$lang['Config_explain'] = "Nedenstende skema giver dig mulighed for at tilpasse alle de generelle forumindstillinger. For Bruger og Forumindstilninger, brug de relaterende links i venstre side.";

$lang['Click_return_config'] = "Klik %sHer%s for at vende tilbage til Generel Konfiguration";

$lang['General_settings'] = "Generelle forumindstillinger";
$lang['Server_name'] = "Domnenavn";
$lang['Server_name_explain'] = "Domnet dette forum ligger p, feks. minside.dk";
$lang['Script_path'] = "Sti til forummet";
$lang['Script_path_explain'] = "Stien til phpBB2 p domnenavnet, feks. /forum/ eller /phpBB2/";
$lang['Server_port'] = "Server Port";
$lang['Server_port_explain'] = "Porten hvorp din server krer. Det er normalt 80, ndre kun hvis ndvendigt";
$lang['Site_name'] = "Sidens navn";
$lang['Site_desc'] = "Beskrivelse af siden";
$lang['Board_disable'] = "Sl forummet fra";
$lang['Board_disable_explain'] = "Dette vil gre forummet utilgngeligt for brugere. Du m ikke logge ud, nr du har slet forummet fra. Du vil ikke kunne logge p igen! Du kan dog ndre denne status direkte i databasen og derigennem genaktivere forummet.";
$lang['Acct_activation'] = "Aktivering af Konto";
$lang['Acc_None'] = "Ingen"; // These three entries are the type of activation
$lang['Acc_User'] = "Bruger";
$lang['Acc_Admin'] = "Administrator";

$lang['Abilities_settings'] = "Generelle Bruger- og Forumindstillinger";
$lang['Max_poll_options'] = "Maksimum antal afstemningsmuligheder";
$lang['Flood_Interval'] = "Sekunder mellem indlg";
$lang['Flood_Interval_explain'] = "Antal sekunder en bruger skal vente, fr et nyt indlg kan skrives."; 
$lang['Board_email_form'] = "Bruger-email via forum";
$lang['Board_email_form_explain'] = "Brugere kan sende hinanden email via dette forum";
$lang['Topics_per_page'] = "Emner pr. side";
$lang['Posts_per_page'] = "Indlg pr. side";
$lang['Hot_threshold'] = "Indlg for populre emner";
$lang['Default_style'] = "Standard layout";
$lang['Override_style'] = "Overskriv brugers valg";
$lang['Override_style_explain'] = "Erstatter brugernes valg med det, der er standard";
$lang['Default_language'] = "Standard Sprog";
$lang['Date_format'] = "Dato Format";
$lang['System_timezone'] = "Tidszone";
$lang['Enable_gzip'] = "Sl GZip Komprimering til";
$lang['Enable_prune'] = "Sl Forumbeskring til";
$lang['Allow_HTML'] = "Tillad HTML";
$lang['Allow_BBCode'] = "Tillad BBCode";
$lang['Allowed_tags'] = "Tilladte HTML kommandoer (tags)";
$lang['Allowed_tags_explain'] = "Adskil kommandoer med kommaer";
$lang['Allow_smilies'] = "Tillad Smilies";
$lang['Smilies_path'] = "Adressen hvor dine Smilies opbevares";
$lang['Smilies_path_explain'] = "Adressen under din phpBB folder, f.eks. images/smilies";
$lang['Allow_sig'] = "Tillad Underskrifter";
$lang['Max_sig_length'] = "Maksimal lngde p underskrifter";
$lang['Max_sig_length_explain'] = "Maksimale antal tegn i brugernes underskrifter";
$lang['Allow_name_change'] = "Tillad, at brugerne kan ndre brugernavn";

$lang['Avatar_settings'] = "Avatar Indstillinger";
$lang['Allow_local'] = "Sl galleri-avatars til";
$lang['Allow_remote'] = "Sl udefra avatars til";
$lang['Allow_remote_explain'] = "Avatars, der befinder sig p en anden hjemmeside";
$lang['Allow_upload'] = "Sl uploading af avatar til";
$lang['Max_filesize'] = "Maksimal strrelse p Avatar-Filer";
$lang['Max_filesize_explain'] = "Glder de avatars, der uploades";
$lang['Max_avatar_size'] = "Maksimal strrelse p Avatars";
$lang['Max_avatar_size_explain'] = "(Hjde x Bredde i pixels)";
$lang['Avatar_storage_path'] = "Adressen hvor Avatars opbevares";
$lang['Avatar_storage_path_explain'] = "Adressen under din phpBB folder, f.eks. images/avatars";
$lang['Avatar_gallery_path'] = "Adressen p Avatar-Galleriet";
$lang['Avatar_gallery_path_explain'] = "Adressen under din phpBB folder, f.eks. images/avatars/gallery";

$lang['COPPA_settings'] = "COPPA Indstillinger";
$lang['COPPA_fax'] = "COPPA Fax Nummer";
$lang['COPPA_mail'] = "COPPA Adresse";
$lang['COPPA_mail_explain'] = "Dette er adressen, hvortil forldre vil sende COPPA blanketterne";

$lang['Email_settings'] = "Email Indstillinger";
$lang['Admin_email'] = "Email adresse p Administrator";
$lang['Email_sig'] = "Email Underskrift";
$lang['Email_sig_explain'] = "Dette tekst vil slutte alle emails, afsendt af forummet";
$lang['Use_SMTP'] = "Brug en SMTP Server til email";
$lang['Use_SMTP_explain'] = "Vlg ja hvis du vil, eller skal, sende email via en specifik server istedet for den normale email funktion.";
$lang['SMTP_server'] = "SMTP Server Adresse";
$lang['SMTP_username'] = "SMTP Brugernavn";
$lang['SMTP_username_explain'] = "Indtast kun et brugernavn, hvis din smtp server krver det";
$lang['SMTP_password'] = "SMTP Kodeord";
$lang['SMTP_password_explain'] = "Indtast kun et kodeord, hvis din smtp server krver det";

$lang['Disable_privmsg'] = "Private Beskeder";
$lang['Inbox_limits'] = "Maksimale antal indlg i Indbakke";
$lang['Sentbox_limits'] = "Maksimale antal indlg i Sendt-bakken";
$lang['Savebox_limits'] = "Maksimale antal indlg i Gemt-bakken";

$lang['Cookie_settings'] = "Cookie indstillinger"; 
$lang['Cookie_settings_explain'] = "Disse kontrollerer hvordan en cookie defineres af en browser. I de fleste tilflde skulle standard indstillingerne vre gode nok. Hvis du har brug for at ndre dem, s pas p, forkerte indstillinger kan resultere i, at brugere ikke kan logge p.";
$lang['Cookie_domain'] = "Cookie domne";
$lang['Cookie_name'] = "Cookie navn";
$lang['Cookie_path'] = "Cookie adresse";
$lang['Cookie_secure'] = "Cookie sikkerhed [ https ]";
$lang['Cookie_secure_explain'] = "Sl dette til hvis din server krer via SSL, ellers lad det vre slet fra";
$lang['Session_length'] = "Lngden p en Session [ sekunder ]";

// Visual Confirmation
$lang['Visual_confirm'] = 'Sl Visuel Bekrftelse til';
$lang['Visual_confirm_explain'] = 'Krver at brugeren indtaster en kode defineret af et billede ved registrering.';

//
// Forum Management
//
$lang['Forum_admin'] = "Forum Administration";
$lang['Forum_admin_explain'] = "Fra denne side kan du tilfje, slette, ndre, omorganisere og gensynkronisere kategorier og forummer.";
$lang['Edit_forum'] = "ndre forum";
$lang['Create_forum'] = "Opret nyt forum";
$lang['Create_category'] = "Opret ny kategori";
$lang['Remove'] = "Fjern";
$lang['Action'] = "Udfr";
$lang['Update_order'] = "Opdatr sortering";
$lang['Config_updated'] = "Forum Konfiguration Korrekt Opdateret";
$lang['Edit'] = "ndre";
$lang['Delete'] = "Slet";
$lang['Move_up'] = "Ryk op";
$lang['Move_down'] = "Ryk ned";
$lang['Resync'] = "Re-synkronisr";
$lang['No_mode'] = "Ingen metode blev valgt";
$lang['Forum_edit_delete_explain'] = "Skemaet nedenfor gr at du kan tilpasse alle de generelle forumindstillinger. For Bruger og det enkelte Forums indstillinger skal du bruge linkene til venstre.";

$lang['Move_contents'] = "Flyt alt indhold";
$lang['Forum_delete'] = "Slet Forum";
$lang['Forum_delete_explain'] = "Skemaet nedenfor lader dig slette et forum (eller en kategori) og bestemme, hvor du vil placere alle emner (eller fora) det/den indeholdt.";

$lang['Status_locked'] = 'Lst';
$lang['Status_unlocked'] = 'Lst op';
$lang['Forum_settings'] = "Generelle Forum Indstillinger";
$lang['Forum_name'] = "Forummets navn";
$lang['Forum_desc'] = "Beskrivelse";
$lang['Forum_status'] = "Forum status";
$lang['Forum_pruning'] = "Automatisk sletning";

$lang['prune_freq'] = 'Tjek for emners alder hver';
$lang['prune_days'] = "Fjern emner, der ikke er blevet skrevet indlg til i";
$lang['Set_prune_data'] = "Du har slet automatisk sletning til for dette forum, men du indtastede ikke et antal dage, hvorefter emner skal slettes. G venligst tilbage og gr dette.";

$lang['Move_and_Delete'] = "Flyt og Slet";

$lang['Delete_all_posts'] = "Slet alle indlg";
$lang['Nowhere_to_move'] = "Ingen steder at flytte til";

$lang['Edit_Category'] = "ndre Kategori";
$lang['Edit_Category_explain'] = "Brug dette skema til at ndre navnet p en kategori.";

$lang['Forums_updated'] = "Forum- og Kategoriinformation korrekt opdateret";

$lang['Must_delete_forums'] = "Du skal slette alle fora, fr du kan slette denne kategori";

$lang['Click_return_forumadmin'] = "Klik %sher%s for at vende tilbage til Forum Administration";


//
// Smiley Management
//
$lang['smiley_title'] = "Smiles Vrktjer";
$lang['smile_desc'] = "Fra denne side, kan du tilfje, slette og ndre de smileys dine brugere kan bruge i deres indlg og private beskeder.";

$lang['smiley_config'] = "Smileyindstillinger";
$lang['smiley_code'] = "Smileykode";
$lang['smiley_url'] = "Smiley Billedfil";
$lang['smiley_emot'] = "Smiley Udtryk";
$lang['smile_add'] = "Tilfj en ny Smiley";
$lang['Smile'] = "Smil";
$lang['Emotion'] = "Udtryk";

$lang['Select_pak'] = "Vlg Pakkefil (.pak)";
$lang['replace_existing'] = "Erstat eksisterende Smiley";
$lang['keep_existing'] = "Behold eksisterende Smiley";
$lang['smiley_import_inst'] = "Du skal pakke zipfilen ud og uploade alle filerne til den pgldende Smiley-folder i din installation.  Vlg herefter de korrekte oplysninger p dette skema for at importere smileypakken.";
$lang['smiley_import'] = "Smiley-pakke-import";
$lang['choose_smile_pak'] = "Vlg en Smileypakke-fil (.pak)";
$lang['import'] = "Importr Smileys";
$lang['smile_conflicts'] = "Hvad skal gres i tilflde af konflikter";
$lang['del_existing_smileys'] = "Slet eksisterende smileys inden import";
$lang['import_smile_pack'] = "Importr Smiley-pakke";
$lang['export_smile_pack'] = "Opret Smiley-pakke";
$lang['export_smiles'] = "For at oprette en smiley-pakke med dine nuvrende installerede smileys, klik %sHer%s for at downloade smiles.pak filen. Giv den et passende navn og srg for at den beholder .pak efternavnet. Lav s en zipfil der indeholder alle smiley-billederne plus denne .pak konfigurationsfil.";

$lang['smiley_add_success'] = "Smileyen blev korrekt tilfjet";
$lang['smiley_edit_success'] = "Smileyen blev korrekt opdateret";
$lang['smiley_import_success'] = "Smiley-pakken blev korrekt importeret!";
$lang['smiley_del_success'] = "Smileyen blev korrekt fjernet";
$lang['Click_return_smileadmin'] = "Klik %sher%s for at vende tilbage til Smiley Administration";


//
// User Management
//
$lang['User_admin'] = "Bruger Administration";
$lang['User_admin_explain'] = "Her kan du ndre dine brugeres informationer og specifikke indstillinger. For at ndre brugernes rettigheder, brug venligst bruger- og gruppe-indstillingssystemet.";

$lang['Look_up_user'] = "Sl bruger op";

$lang['Admin_user_fail'] = "Brugerens profil kunne ikke opdaters.";
$lang['Admin_user_updated'] = "Brugerens profil blev korrekt opdateret.";
$lang['Click_return_useradmin'] = "Klik %sher%s for at vende tilbage til Bruger Administration";

$lang['User_delete'] = "Slet denne bruger";
$lang['User_delete_explain'] = "Klik her for at slette denne bruger. Det er permenent.";
$lang['User_deleted'] = "Brugeren blev korrekt slettet.";

$lang['User_status'] = "Brugeren er aktiv";
$lang['User_allowpm'] = "Kan sende Private Beskeder";
$lang['User_allowavatar'] = "Kan vise en avatar";

$lang['Admin_avatar_explain'] = "Her kan du se og slette brugerens nuvrende avatar.";

$lang['User_special'] = "Specielle kun-administrator felter";
$lang['User_special_explain'] = "Disse felter kan ikke ndres af brugerne. Her kan du bestemme deres status og ndre indstillinger, de ikke har adgang til.";


//
// Group Management
//
$lang['Group_administration'] = "Gruppe Administration";
$lang['Group_admin_explain'] = "Fra dette panel kan du administere alle dine brugergrupper, du kan slette, oprette og ndre eksisterende grupper. Du kan vlge redaktrer, sl grupper til og fra og bestemme gruppens navn og beskrivelse";
$lang['Error_updating_groups'] = "Der opstod en fejl under opdateringen af grupperne";
$lang['Updated_group'] = "Gruppen blev korrekt opdateret";
$lang['Added_new_group'] = "Den nye gruppe blev korrekt oprettet";
$lang['Deleted_group'] = "Gruppen blev korrekt slettet";
$lang['New_group'] = "Opret en ny gruppe";
$lang['Edit_group'] = "ndre gruppe";
$lang['group_name'] = "Gruppens navn";
$lang['group_description'] = "Gruppens beskrivelse";
$lang['group_moderator'] = "Grupperedaktr";
$lang['group_status'] = "Gruppestatus";
$lang['group_open'] = "ben gruppe";
$lang['group_closed'] = "Lukket gruppe";
$lang['group_hidden'] = "Skjult gruppe";
$lang['group_delete'] = "Slet gruppe";
$lang['group_delete_check'] = "Slet denne gruppe";
$lang['submit_group_changes'] = "Tilfj ndringer";
$lang['reset_group_changes'] = "Nulstil ndringer";
$lang['No_group_name'] = "Du skal vlge et navn til denne gruppe";
$lang['No_group_moderator'] = "Du skal vlge en redaktr til denne gruppe";
$lang['No_group_mode'] = "Du skal vlge en status for denne gruppe, ben eller lukket";
$lang['No_group_action'] = 'Ingen metode valgt';
$lang['delete_group_moderator'] = "Slet den gamle grupperedaktr?";
$lang['delete_moderator_explain'] = "Hvis du ndrer grupperedaktren, st kryds i dette felt for at slette den gamle redaktr fra gruppen. Hvis du ikke stter kryds, bliver brugeren et normalt medlem af gruppen.";
$lang['Click_return_groupsadmin'] = "Klik %sher%s for at vende tilbage til Gruppe Administration.";
$lang['Select_group'] = "Vlg en gruppe";
$lang['Look_up_group'] = "Vis Gruppe";


//
// Prune Administration
//
$lang['Forum_Prune'] = "Forum Beskring";
$lang['Forum_Prune_explain'] = "Dette vil slette enhvert emne, som der ikke er skrevet indlg til, i det antal dage du vlger. Hvis du ikke indtaster et nummer, bliver alle emner slettet. Emner, hvor der stadig er bne afstemninger, vil ikke blive slettet, ligesom Annonceringer heller ikke slettes. Du skal slette disse emner manuelt.";
$lang['Do_Prune'] = "Udfr beskring";
$lang['All_Forums'] = "Alle Fora";
$lang['Prune_topics_not_posted'] = "Slet emner uden nye indlg i";
$lang['Topics_pruned'] = "Emner slettet";
$lang['Posts_pruned'] = "Indlg slettet";
$lang['Prune_success'] = "Vellykket beskring af fora";


//
// Word censor
//
$lang['Words_title'] = "Censurering af ord";
$lang['Words_explain'] = "Fra denne side kan du tilfje, ndre og fjerne ord, der automatisk censureres i dine fora. Folk kan heller ikke registrere med et brugernavn, der indeholder disse ord. Jokere (*) kan bruges i ordfelterne, f.eks. *test* vil matche utestet, test* vil matche tester, *test ville matche utest.";
$lang['Word'] = "Ord";
$lang['Edit_word_censor'] = "ndre ordcensurr";
$lang['Replacement'] = "Erstatning";
$lang['Add_new_word'] = "Tilfj nyt ord";
$lang['Update_word'] = "Opdatr ordcensurr";

$lang['Must_enter_word'] = "Du skal indtaste et ord og det ords erstatning";
$lang['No_word_selected'] = "Intet ord er valgt til ndring";

$lang['Word_updated'] = "Den valgte ordcensur blev korrekt opdateret";
$lang['Word_added'] = "Ordcensuren blev korrekt tilfjet";
$lang['Word_removed'] = "Den valgte ordcensur blev korrekt fjernet";

$lang['Click_return_wordadmin'] = "Klik %sher%s for at vende tilbage til Censurering af ord";


//
// Mass Email
//
$lang['Mass_email_explain'] = "Her kan du sende email til alle dine brugere eller alle brugere i en specifik gruppe. For at gre dette bliver en email sendt til alle de administrative email adresser, og en kopi sendes til alle modtagere. Hvis du emailer en stor gruppe mennesker, skal du vre tlmodig, da det godt kan tage lang tid at sende mailen til en stor gruppe. Stop ikke siden nr den er halvvejs, da processen vil g i st, og ikke alle i den angivne gruppe vil modtage emailen. Du fr at vide, nr mailen er frdigsendt.";
$lang['Compose'] = "Skriv"; 

$lang['Recipients'] = "Modtagere"; 
$lang['All_users'] = "Alle Brugere";

$lang['Email_successfull'] = "Din besked er afsendt";
$lang['Click_return_massemail'] = "Klik %sher%s for at vende tilbage til Gruppe email";


//
// Ranks admin
//
$lang['Ranks_title'] = "Rang-administration";
$lang['Ranks_explain'] = "Ved at bruge denne side kan du tilfje, ndre, se og slette rang-niveauer. Du kan ogs oprette specifikke niveauer, som kan gives til en bruger gennem brugervrktjerne.";

$lang['Add_new_rank'] = "Tilfj ny rang";

$lang['Rank_title'] = "Rangtitel";
$lang['Rank_special'] = "Lav til Speciel Rang";
$lang['Rank_minimum'] = "Minimum Indlg";
$lang['Rank_maximum'] = "Maksimum Indlg";
$lang['Rank_image'] = "Rang-billede (Relativt ift. phpBB2 hovedfolderen)";
$lang['Rank_image_explain'] = "Bestem her, om et lille billede skal bruges sammen med rangen.";

$lang['Must_select_rank'] = "Du skal vlge en rang";
$lang['No_assigned_rank'] = "Ingen speciel rang tilvalgt";

$lang['Rank_updated'] = "Rangen blev korrekt opdateret";
$lang['Rank_added'] = "Rangen blev korrekt tilfjet";
$lang['Rank_removed'] = "Rangen blev korrekt slettet";
$lang['No_update_ranks'] = 'Rangen blev korrekt slettet. Brugerkonti med denne rang blev dog ikke opdateret.  Du er ndt til manuelt at nulstille rangen for disse konti';

$lang['Click_return_rankadmin'] = "Klik %sher%s for at vende tilbage til Niveau Administration";


//
// Disallow Username Admin
//
$lang['Disallow_control'] = "Forbyd Brugernavn Vrktjer";
$lang['Disallow_explain'] = "Her kan du kontrollere, hvilke brugernavne der er tilladt. Forbudte brugernavne m indeholde en joker, betegnet som et *. Bemrk venligst, at du ikke kan forbyde et brugernavn, der allerede er registreret, du skal frst slette navnet og derefter forbyde det.";

$lang['Delete_disallow'] = "Slet";
$lang['Delete_disallow_title'] = "Fjern et forbudt brugernavn";
$lang['Delete_disallow_explain'] = "Du kan fjerne et forbudt brugernavn ved at vlge brugernavnet fra denne liste og trykke p knappen";

$lang['Add_disallow'] = "Tilfj";
$lang['Add_disallow_title'] = "Tilfj et forbudt brugernavn";
$lang['Add_disallow_explain'] = "Du kan forbyde et brugernavn ved at bruge jokeren * istedet for et tegn";

$lang['No_disallowed'] = "Ingen forbudte brugernavne";

$lang['Disallowed_deleted'] = "Det forbudte brugernavn blev succesfuldt fjernet";
$lang['Disallow_successful'] = "Det forbudte brugernavn blev korrekt tilfjet";
$lang['Disallowed_already'] = "Navnet du indtastede kunne ikke forbydes. Enten eksisterer det allerede i listen, eksisterer i ordcensureringslisten, eller en bruger har det brugernavn";

$lang['Click_return_disallowadmin'] = "Klik %sher%s for at vende tilbage til Forbyd Brugernavn Vrktjer";


//
// Styles Admin
//
$lang['Styles_admin'] = "Layout Administration";
$lang['Styles_explain'] = "Ved brug af disse vrktjer kan du tilfje, fjerne og ndre layouts (formskemaer og design), der er tilgngelige for dine brugere";
$lang['Styles_addnew_explain'] = "Den flgende liste indeholder alle de designs, der er tilgngelige for de formskemaer, du har. Navnene p listen er endnu ikke installeret i phpBB databasen. For at installere skal du bare klikke p installr linket ved siden af navnet";

$lang['Select_template'] = "Vlg et formskema";

$lang['Style'] = "Layout";
$lang['Template'] = "Formskema";
$lang['Install'] = "Installr";
$lang['Download'] = "Download";

$lang['Edit_theme'] = "ndre Design";
$lang['Edit_theme_explain'] = "I skemaet nedenunder kan du ndre indstillingerne for det valgte design";

$lang['Create_theme'] = "Opret Design";
$lang['Create_theme_explain'] = "Brug skemaet nedenunder for at oprette et nyt design til det valgte formskema. Nr du indtaster farver (for hvilket du skal bruge hexadecimal systemet) skal du ikke bruge # tegnet, f.eks. CCCCCC er brugbart, #CCCCCC er ikke";

$lang['Export_themes'] = "Eksportr Designs";
$lang['Export_explain'] = "I dette panel kan du eksportere design-dataen for et valgt formskema. Vlg formskemaet fra listen nedenunder og databasen vil skabe design konfigurationsfilen og forsge at gemme den i det valgte formskemas bibliotek. Hvis den ikke kan gemme filen, vil du f muligheden for, at downloade den. For at databasen kan gemme filen, skal du give den lov til at gemme i biblioteket for det valgte formskema. For mere information om dette, se phpBB2 Brugerguiden.";

$lang['Theme_installed'] = "Det valgte design blev korrekt installeret.";
$lang['Style_removed'] = "Det valgte design blev korrekt fjernet fra databasen. For permanent at fjerne dette design fra dit system, skal du slette designet fra dit formskema bibliotek.";
$lang['Theme_info_saved'] = "Design informationen for det valgte formskema er blevet gemt. Du skal nu give rettighederne tilbage i theme_info.cfg filen (og hvis du nsker, stte det valgte formskema bibliotek) til ls-kun (read-only)";
$lang['Theme_updated'] = "Det valgte design er opdateret. Du skal nu eksportere de nye design indstillinger";
$lang['Theme_created'] = "Design oprettet. Du skal nu eksportere designet og design konfigurationsfilen som backup eller brug andensteds.";

$lang['Confirm_delete_style'] = "Er du sikker p, at du vil slette dette layout";

$lang['Download_theme_cfg'] = "Databasen kunne ikke skrive til design informationsfilen. Klik p knappen nedenunder for at downloade filen. Nr den er downloadet skal du uploade den i det bibliotek, der indeholder formskema filerne. Du kan s pakke filerne til distribution eller brug andensteds, hvis du nsker.";
$lang['No_themes'] = "Formskemaet du valgte, har ingen designs. For at oprette et nyt design skal du klikke p Opret Nyt Design i venstre side";
$lang['No_template_dir'] = "Formskema biblioteket kunne ikke bnes. Det er muligvis ikke lseligt af serveren eller ogs eksisterer det ikke.";
$lang['Cannot_remove_style'] = "Du kan ikke fjerne layoutet eftersom det p nuvrende tidspunkt er det layout, der er standard for forummet. ndre standardlayoutet og prv igen.";
$lang['Style_exists'] = "Det valgte layout navn eksisterer allerede, g venligst tilbage og vlg et andet.";

$lang['Click_return_styleadmin'] = "Klik %sher%s for at vende tilbage til Layout Administration";

$lang['Theme_settings'] = "Design indstillinger";
$lang['Theme_element'] = "Design Element";
$lang['Simple_name'] = "Simpelt Navn";
$lang['Value'] = "Vrdi";
$lang['Save_Settings'] = "Gem Indstillinger";

$lang['Stylesheet'] = "CSS Stylesheet";
$lang['Background_image'] = "Baggrundsbillede";
$lang['Background_color'] = "Baggrundsfarve";
$lang['Theme_name'] = "Design Navn";
$lang['Link_color'] = "Linkfarve";
$lang['Text_color'] = "Tekstfarve";
$lang['VLink_color'] = "Besgt Linkfarve";
$lang['ALink_color'] = "Aktiv Linkfarve";
$lang['HLink_color'] = "Svver Linkfarve";
$lang['Tr_color1'] = "Tabelrkke Farve 1";
$lang['Tr_color2'] = "Tabelrkke Farve 2";
$lang['Tr_color3'] = "Tabelrkke Farve 3";
$lang['Tr_class1'] = "Tabelrkke Klasse 1";
$lang['Tr_class2'] = "Tabelrkke Klasse 2";
$lang['Tr_class3'] = "Tabelrkke Klasse 3";
$lang['Th_color1'] = "Tabeltop Farve 1";
$lang['Th_color2'] = "Tabeltop Farve 2";
$lang['Th_color3'] = "Tabeltop Farve 3";
$lang['Th_class1'] = "Tabeltop Klasse 1";
$lang['Th_class2'] = "Tabeltop Klasse 2";
$lang['Th_class3'] = "Tabeltop Klasse 3";
$lang['Td_color1'] = "Tabelcelle Farve 1";
$lang['Td_color2'] = "Tabelcelle Farve 2";
$lang['Td_color3'] = "Tabelcelle Farve 3";
$lang['Td_class1'] = "Tabelcelle Klasse 1";
$lang['Td_class2'] = "Tabelcelle Klasse 2";
$lang['Td_class3'] = "Tabelcelle Klasse 3";
$lang['fontface1'] = "Skrifttype 1";
$lang['fontface2'] = "Skrifttype 2";
$lang['fontface3'] = "Skrifttype 3";
$lang['fontsize1'] = "Skriftstrrelse 1";
$lang['fontsize2'] = "Skriftstrrelse 2";
$lang['fontsize3'] = "Skriftstrrelse 3";
$lang['fontcolor1'] = "Skriftfarve 1";
$lang['fontcolor2'] = "Skriftfarve 2";
$lang['fontcolor3'] = "Skriftfarve 3";
$lang['span_class1'] = "Span Klasse 1";
$lang['span_class2'] = "Span Klasse 2";
$lang['span_class3'] = "Span Klasse 3";
$lang['img_poll_size'] = "Afstemningsbillede Strrelse [px]";
$lang['img_pm_size'] = "Private Beskeder Status Strrelse [px]";


//
// Install Process
//
$lang['Welcome_install'] = "Velkommen til phpBB 2 Installationen";
$lang['Initial_config'] = "Generel Konfiguration";
$lang['DB_config'] = "Database Konfiguration";
$lang['Admin_config'] = "Administrator Konfiguration";
$lang['continue_upgrade'] = "Nr du har downloadet din config fil til din harddisk, kan du\"Fortst Opgradering\" knap nedenunder for at for at fortstte opgraderingen. Vent venligst med at uploade config filen indtil opgraderingen er frdig.";
$lang['upgrade_submit'] = "Fortst Opgradering";

$lang['Installer_Error'] = "En fejl opstod under installationen";
$lang['Previous_Install'] = "En tidligere installation er fundet";
$lang['Install_db_error'] = "En fejl opstod under forsget p at opgradere databasen";

$lang['Re_install'] = "Din tidligere installation er stadig aktiv. <br /><br />Hvis du vil geninstallere phpBB 2 skal du klikke p Ja knappen nedenunder. Bemrk venligst, at hvis du gr det, vil det slette alle eksisterende data. Ingen backups vil blive lavet! Det administrator brugernavn og kodeord du har brugt til at logge p forummet, vil blive genskabt efter geninstallationen. Ingen andre indstillinger bliver gemt. <br /><br />Tnk dig om inden du trykker Ja!";

$lang['Inst_Step_0'] = "Tak fordi du valgte phpBB 2. For at frdiggre installationen skal du indtaste de relevante oplysninger nedenunder. Bemrk venligst, at den database du installer i, skal allerede vre oprettet. Hvis du installerer en database, der bruger ODBC, f.eks. MS Access skal du oprette en DSN for den inden du fortstter.";

$lang['Start_Install'] = "Start Installation";
$lang['Finish_Install'] = "Frdiggr Installation";

$lang['Default_lang'] = "Standardsproget p forummet";
$lang['DB_Host'] = "Database Server Hostname / DSN";
$lang['DB_Name'] = "Navnet p din Database";
$lang['DB_Username'] = "Database Brugernavn";
$lang['DB_Password'] = "Database Kodeord";
$lang['Database'] = "Din Database";
$lang['Install_lang'] = "Vlg Sprog for Installationen";
$lang['dbms'] = "Database Type";
$lang['Table_Prefix'] = "Fornavn for tabeller i databasen";
$lang['Admin_Username'] = "Administrator Brugernavn";
$lang['Admin_Password'] = "Administrator Kodeord";
$lang['Admin_Password_confirm'] = "Administrator Kodeord [ Bekrft ]";

$lang['Inst_Step_2'] = "Dit administrator brugernavn er oprettet.  P nuvrende tidspunkt er den basale installation frdig. Du bliver nu sendt videre til en side, hvor du kan administrere din nye installation. Tjek venligst de Generelle Konfigurations indstillinger og lav de nskede ndringer. Tak fordi du valgte phpBB 2.";

$lang['Unwriteable_config'] = "Der kan i jeblikket ikke skrives til din config fil. En kopi af config filen vil blive downloadet til dig, nr du trykker p knappen nedenunder. Du skal uploade denne fil til det samme bibliotek, som phpBB 2. Nr dette er gjort, skal du logge p, med dit administrator navn og kodeord du valgte p det forrige skema, og g ind p administrator kontrol centeret (et link vil vre tilgngeligt nederst p hver side, nr frst du er logget p) for at tjekke den genrelle konfiguration. Tak fordi du valgte phpBB 2.";
$lang['Download_config'] = "Download Config";

$lang['ftp_choose'] = "Vlg Download Metode";
$lang['ftp_option'] = "<br />Eftersom FTP udvidelser er tilgngelige i denne version af PHP kan du ogs frst prve automatisk at uploade config filen til det rette bibliotek.";
$lang['ftp_instructs'] = "Du har valgt automatisk at uploade filen til det bibliotek, der indeholder phpBB 2.  Indtast venligst de krvede oplysninger nedenunder, s den automatiske uploading kan foretages. Bemrk at FTP adressen skal vre den njagtige adresse via FTP til din phpBB2 installation, som hvis du brugte en FTP klient til at uploade filen.";
$lang['ftp_info'] = "Indtast din FTP Information";
$lang['Attempt_ftp'] = "Forsg at uploade config filen til det passende bibliotek";
$lang['Send_file'] = "Bare send filen til mig og s uploader jeg den manuelt";
$lang['ftp_path'] = "FTP adresse til phpBB 2";
$lang['ftp_username'] = "Dit FTP Brugernavn";
$lang['ftp_password'] = "Dit FTP Kodeord";
$lang['Transfer_config'] = "Start Upload";
$lang['NoFTP_config'] = "Forsget p automatisk at uploade config filen slog fejl. Download venligst filen og upload den manuelt.";

$lang['Install'] = "Installr";
$lang['Upgrade'] = "Opgradr";


$lang['Install_Method'] = "Vlg installationsmetode";

$lang['Install_No_Ext'] = "Php Konfigurationen p din server understtter ikke den type af database, som du har valgt"; 

$lang['Install_No_PCRE'] = "PhpBB2 krver Perl-Compatible Regular Expressions-modulet til PHP, hvilket din php konfiguration ikke lader til at understtte!"; 

//
// That's all Folks!
// -------------------------------------------------

?>
